<?php

namespace PlagScanApi;

require_once  __DIR__ . '/Base.php';
/**
 * Class Submissions
 * @author Ingmar Szmais <iszmais@databay.de>
 * @since 20.08.19
 */
class Submissions extends Base
{

    /**
     * @param int $userID
     * @return array|string
     */
    public function getAll(int $userID = 0)
    {
        $data = [];
        if ($userID) {
            $data['ownerID'] = $userID;
        }

        return $this->handler->request('submissions', 'GET', $this->accessToken, $data);
    }

    /**
     * @param string $title
     * @param int $maxUploads
     * @param int $share
     * @param int $checkDeadline
     * @param int $notifyDeadline
     * @param int $enableResubmission
     * @param int $checkOnUpload
     * @param int $type
     * @param array $configuration
     * @return array|string
     */
    public function add(
        string $title,
        int $maxUploads,
        int $share,
        int $checkDeadline,
        int $notifyDeadline,
        int $enableResubmission,
        int $checkOnUpload,
        int $type,
        array $configuration = []
    )
    {
        $data['title'] = $title;
        $data['maxUploads'] = $maxUploads;
        $data['share'] = $share;
        $data['checkDeadline'] = $checkDeadline;
        $data['notifyDeadline'] = $notifyDeadline;
        $data['enableResubmission'] = $enableResubmission;
        $data['checkOnUpload'] = $checkOnUpload;
        $data['type'] = $type;

        $data = $data + $configuration;

        return $this->handler->request('submissions', 'POST', $this->accessToken, $data);
    }

    /**
     * @param int $submissionID
     * @param array $changes
     * @return array|string
     */
    public function change(int $submissionID, array $changes)
    {
        return $this->handler->request('submissions/' . $submissionID, 'PATCH', $this->accessToken, $changes);
    }

    /**
     * @param int $submissionID
     * @return array|string
     */
    public function delete(int $submissionID)
    {
        return $this->handler->request('submissions/' . $submissionID, 'DELETE', $this->accessToken);
    }

    /**
     * @param int $submissionID
     * @param int $userID
     * @return array|string
     */
    public function getDocuments(int $submissionID, int $userID)
    {
        $data['ownerID'] = $userID;
        return $this->handler->request('submissions/' . $submissionID . '/documents', 'GET', $this->accessToken, $data);
    }

    /**
     * @param int $submissionID
     * @param string $fileUpload
     * @param string $title
     * @param string $firstname
     * @param string $lastname
     * @param string $email
     * @param int $sendResults
     * @param int $saveOrigin
     * @return array|string
     */
    public function addDocument(
        int $submissionID,
        string $fileUpload,
        string $title,
        string $firstname,
        string $lastname,
        string $email,
        int $sendResults = 0,
        int $saveOrigin = 0
    )
    {
        $data['fileUpload'] = $fileUpload;
        $data['title'] = $title;
        $data['firstname'] = $firstname;
        $data['lastname'] = $lastname;
        $data['email'] = $email;
        $data['sendResults'] = $sendResults;
        $data['saveOrig'] = $saveOrigin;
        return $this->handler->request('submissions/' . $submissionID, 'POST', $this->accessToken, $data);
    }

    /**
     * @param int $submissionID
     * @param int $docID
     * @param string $fileUpload
     * @param int $saveOrigin
     * @return array|string
     */
    public function replaceDocument(int $submissionID, int $docID, string $fileUpload, int $saveOrigin = 0)
    {
        $data['docID'] = $docID;
        $data['fileUpload'] = $fileUpload;
        $data['saveOrig'] = $saveOrigin;
        return $this->handler->request('submissions/' . $submissionID, 'POST', $this->accessToken, $data);
    }
}