<?php
/* Copyright (c) 1998-2019 ILIAS open source, Extended GPL, see docs/LICENSE */

/**
 * @author Michael Jansen <mjansen@databay.de> 
 */

use ILIAS\Filesystem\Stream\Streams;

$iliasRootDirectory = './';
$cookiePath = dirname($_SERVER['PHP_SELF']);
$requestUri = $_SERVER['REQUEST_URI'];

$i = 0;
while (!file_exists($iliasRootDirectory . 'ilias.ini.php') && $i < 20) {
    $iliasRootDirectory .= '../';
    ++$i;

    $cookiePath = dirname($cookiePath);
    $requestUri = dirname($requestUri);
}
chdir($iliasRootDirectory);

if (!file_exists(getcwd() . '/ilias.ini.php')) {
    die('Please ensure ILIAS is installed!');
}

$cookiePath .= (!preg_match("/[\/|\\\\]$/", $cookiePath)) ? "/" : "";

if (isset($_GET['client_id'])) {
    if ($cookiePath == "\\") {
	$cookiePath = '/';
    }

    setcookie('ilClientId', $_GET['client_id'], 0, $cookiePath, '');
    $_COOKIE['ilClientId'] = $_GET['client_id'];
}
define('IL_COOKIE_PATH', $cookiePath);

$_SERVER['REQUEST_URI'] = dirname($requestUri) . '/' . basename($_SERVER['REQUEST_URI']);
$_SERVER['PHP_SELF'] = str_replace('?' . $_SERVER['QUERY_STRING'], '', $_SERVER['REQUEST_URI']);

global $DIC;

require_once 'Services/Init/classes/class.ilInitialisation.php';
ilInitialisation::initILIAS();

$authStatus = \ilAuthStatus::getInstance();

$authCredentials = new class((string) ($_GET['token'] ?? '')) extends ilAuthFrontendCredentials implements ilAuthCredentials
{
    /** @var string */
    private $token;

    /**
     *  constructor.
     * @param string $token
     */
    public function __construct(string $token)
    {
	$this->token = $token;
    }

    /**
     * @return string
     */
    public function getToken() : string
    {
	return $this->token;
    }
};

$authProvider = new class($authCredentials) extends ilAuthProvider implements ilAuthProviderInterface
{
    /**
     * Provider constructor.
     * @param \ilAuthCredentials $credentials
     */
    public function __construct(\ilAuthCredentials $credentials)
    {
	parent::__construct($credentials);
    }

    /**
     * @inheritDoc
     */
    public function doAuthentication(ilAuthStatus $status)
    {
	global $DIC;

	$token = $this->getCredentials()->getToken();

	// TODO: Token could be looked up in the database, a mapped user account (it's id) should be returned
	//$valid = strlen($token) > 0;
	$valid = true;
	if ($valid) {
	    $status->setStatus(\ilAuthStatus::STATUS_AUTHENTICATED);
	    $status->setAuthenticatedUserId(6); // TODO: Set any Valid ILIAS user id (mapped to the token)
	    return true;
	}

	$status->setStatus(ilAuthStatus::STATUS_AUTHENTICATION_FAILED);
	$status->setTranslatedReason('Invalid authentication token given');
	// OR: $status->setReason('language_variable');

	return false;
    }
};

$authFrontend = new class(
    $GLOBALS['DIC']['ilAuthSession'],
    $authStatus,
    $authCredentials,
    [$authProvider]
) extends ilAuthFrontendWS
{
    /**
     * @inheritdoc
     */
    protected function handleAuthenticationSuccess(\ilAuthProviderInterface $provider)
    {
	return parent::handleAuthenticationSuccess($provider);
    }
};

$authFrontend->authenticate();

$http = $DIC->http();
$response = $http->response();
switch ($authStatus->getStatus()) {
    case ilAuthStatus::STATUS_AUTHENTICATED:
	$http->saveResponse($response->withStatus(200));
	$response =  $response = $response
	    ->withStatus(200)
	    ->withHeader('Content-Type', 'application/json; charset=UTF-8;')
	    ->withBody($stream = Streams::ofString(json_encode([
		'status' => 'authenticated'
	    ])));
	$http->saveResponse($response);
	if(isset($_REQUEST['docID'])) {
	triggerUpdate((int)$_REQUEST['docID']);
	}
	break;

    case ilAuthStatus::STATUS_AUTHENTICATION_FAILED:
	$response = $http->response();
	$http->saveResponse($response->withStatus(401));
	break;
}
$http->sendResponse();

function triggerUpdate($docID)
{
    require_once './Customizing/global/plugins/Services/UIComponent/UserInterfaceHook/PlagScanExercise/classes/class.ilPlagScanDocumentManagement.php';
    ilPlagScanDocumentManagement::checkDocument($docID);
}